@@ -16,7 +16,7 @@
 __author__ = "Vasyl Khomenko"
 __copyright__ = "Copyright 2013, Qubell.com"
 __license__ = "Apache"
-__version__ = "1.0.14"
+__version__ = "1.0.15"
 __email__ = "vkhomenko@qubell.com"
 
 import logging as log
@@ -28,12 +28,12 @@ from qubell.api.private import exceptions
 
 class QubellPlatform(object):
 
-    def __init__(self, auth):
+    def __init__(self, auth, context=None):
         self.organizations = []
-        self.auth = auth
-        self.user = auth.user
-        self.password = auth.password
-        self.tenant = auth.tenant
+        self.auth = context | auth
+        self.user = self.auth.user
+        self.password = self.auth.password
+        self.tenant = self.auth.tenant
 
     def authenticate(self):
         url = self.auth.api+'/signIn'
